==> psitransfer-2.0.1.tgz: package/lang/de.js <==
module.exports = {
  langCode: "de",
  oldBrowserError: "Ihr zu alter Browser unterstützt diese Funktion nicht.",
  dropFilesHere: "Dateien hier fallen lassen.",
  noPreviewAvailable: "Keine Vorschau verfügbar",
  preview: "Vorschau",
  comment: "Kommentar",
  settings: "Einstellungen",
  retention: "Aufbewahrung",
  password: "Passwort",
  required: "erforderlich",
  optional: "optional",
  generateRandomPassword: "Zufälliges Passwort erstellen",
  newUpload: "Neuer Upload",
  accessDenied: "Zugriff verweigert!",
  login: "Login",
  email: "E-Mail",
  sendViaMail: "Per E-Mail verschicken",
  showQrCode: "QR-Code anzeigen",
  clipboard: "Zwischenablage",
  copyToClipboard: "In die Zwischenablage kopieren",
  uploadCompleted: "Upload vollständig",
  downloadLink: "Download Link",
  upload: "hochladen",
  retry: "erneut versuchen",
  createNewUploadSession: "Neue Upload-Session erstellen?",
  decrypt: "entschlüsseln",
  files: "Dateien",
  zipDownload: "Alle Dateien als ZIP herunterladen (kann nicht fortgesetzt werden)",
  tarGzDownload: "Alle Dateien als tar.gz herunterladen (kann nicht fortgesetzt werden)",
  oneTimeDownloadExpired: "Einmal-Download: Datei ist nicht mehr verfügbar.",
  fileSizeExceed: "Dateigröße %% überschreitet das Maximum von %%",
  bucketSizeExceed: "Uploadgröße %% überschreitet das Maximum von %%",
  mailInvalid: "Das Format der E-Mail Adresse ist ungültig",
  mailTo: "Senden an",
  mailToPlaceholder: "E-Mail Adressen",
  mailFrom: "Meine E-Mail Adresse",
  mailFromPlaceholder: "E-Mail Adresse",
  mailMessage: "Meine Nachricht",
  mailDownloadNotification: "Benachrichtige mich, wenn eine Datei heruntergeladen wurde.",
  mailSendBtn: "E-Mail verschicken",
  mailsSent: "Die E-Mails wurden verschickt.",
  mailSubjectUploader: "PsiTransfer Datei-Upload",
  mailSubjectDownloader: "PsiTransfer Datei-Download",
  mailSubjectFileDownloaded: "Datei wurde heruntergeladen",
  retentions: {
    "one-time": "Einmal-Download",
    "3600": "1 Stunde",
    "21600": "6 Stunden",
    "86400": "1 Tag",
    "259200": "3 Tage",
    "604800": "1 Woche",
    "1209600": "2 Wochen",
    "2419200": "4 Wochen",
    "4838400": "8 Wochen"
  },
}

==> psitransfer-2.2.0.tgz: package/lang/de.js <==
module.exports = {
  langCode: "de",
  oldBrowserError: "Ihr zu alter Browser unterstützt diese Funktion nicht.",
  dropFilesHere: "Dateien hier ablegen.",
  noPreviewAvailable: "Keine Vorschau verfügbar",
  preview: "Vorschau",
  comment: "Kommentar",
  settings: "Einstellungen",
  retention: "Aufbewahrungsdauer",
  password: "Passwort",
  required: "erforderlich",
  optional: "optional",
  generateRandomPassword: "Zufälliges Passwort erstellen",
  newUpload: "Neuer Upload",
  accessDenied: "Zugriff verweigert!",
  login: "Login",
  email: "E-Mail",
  sendViaMail: "Per E-Mail verschicken",
  showQrCode: "QR-Code anzeigen",
  clipboard: "Zwischenablage",
  copyToClipboard: "In die Zwischenablage kopieren",
  uploadCompleted: "Upload vollständig",
  downloadLink: "Download Link",
  upload: "hochladen",
  retry: "erneut versuchen",
  createNewUploadSession: "Neue Upload-Session erstellen?",
  decrypt: "entschlüsseln",
  files: "Dateien",
  zipDownload: "Alle Dateien als ZIP herunterladen (kann nicht fortgesetzt werden)",
  tarGzDownload: "Alle Dateien als tar.gz herunterladen (kann nicht fortgesetzt werden)",
  oneTimeDownloadExpired: "Einmal-Download: Datei ist nicht mehr verfügbar.",
  fileSizeExceed: "Dateigröße %% überschreitet das Maximum von %%",
  bucketSizeExceed: "Uploadgröße %% überschreitet das Maximum von %%",
  mailInvalid: "Das Format der E-Mail Adresse ist ungültig",
  mailTo: "Senden an",
  mailToPlaceholder: "E-Mail Adressen",
  mailFrom: "Meine E-Mail Adresse",
  mailFromPlaceholder: "E-Mail Adresse",
  mailMessage: "Meine Nachricht",
  mailDownloadNotification: "Benachrichtige mich, wenn eine Datei heruntergeladen wurde.",
  mailSendBtn: "E-Mail verschicken",
  mailsSent: "Die E-Mails wurden verschickt.",
  mailSubjectUploader: "PsiTransfer Datei-Upload",
  mailSubjectDownloader: "PsiTransfer Datei-Download",
  mailSubjectFileDownloaded: "Datei wurde heruntergeladen",
  retentions: {
    "one-time": "Einmal-Download",
    "3600": "1 Stunde",
    "21600": "6 Stunden",
    "86400": "1 Tag",
    "259200": "3 Tage",
    "604800": "1 Woche",
    "1209600": "2 Wochen",
    "2419200": "4 Wochen",
    "4838400": "8 Wochen"
  },
}
